@@ -16,6 +16,13 @@ where
                 black_box(input);
             }),
         ),
+        (
+            "rdst_inplace",
+            Box::new(|mut input| {
+                input.radix_sort_inplace_unstable();
+                black_box(input);
+            }),
+        ),
         (
             "voracious",
             Box::new(|mut input| {
